/*
 *
 * Copyright 2025 tofuutils authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package tofuurl

import githuburl "github.com/tofuutils/tenv/v4/pkg/github/url"

const (
	Get       = "https://get.opentofu.org/"
	Github    = githuburl.Default + "opentofu/opentofu" + githuburl.SlashReleasesSuffix
	PublicKey = Get + "opentofu.asc"
)
